--[[
	FlameWarden UI: display which year the various fires were last desecrated in.
	
	To get our modified to display, inject a custom GetAchievementCriteriaInfo into
	the environment of AchievementObjectives_DisplayCriteria: this ensures minimal
	disruption to any other functional area.
]]

local orig, env, cyear = GetAchievementCriteriaInfo, setmetatable({}, {__index=_G});
local achievementCompleted, achievementID;

local function process(id, ...)
	local name, ctype, lcompleted = ...;
	if achievementID ~= id then 
		achievementID, achievementCompleted = id, select(4, GetAchievementInfo(id));
	end
	local check = id > 1027 and FlameWarden.IsZoneDesecrated or FlameWarden.IsZoneHonoured;
	if type(check) == "function" then
		local year, color = check(name);
		if year and lcompleted then 
			cyear = cyear or select(4, CalendarGetDate());
			if year ~= cyear then
				color = achievementCompleted and "800000" or "ff8000";
			else
				color = achievementCompleted and "004000" or "00ff00";
			end
			return ("%s |cff%s(%s)|r"):format((...), color, year), select(2, ...);
		end
	end
	return ...;
end
function env.GetAchievementCriteriaInfo(...)
	local id, i = ...;
	if type(id) ~= "number" or id < 1022 or id > 1033 or i == nil then return orig(...); end
	return process(id, orig(...));
end

FlameWardenEventTracker:RegisterEvent("ADDON_LOADED");
function FlameWardenEventTracker:ADDON_LOADED(addon)
	if addon == "Blizzard_AchievementUI" then
		setfenv(AchievementObjectives_DisplayCriteria, env)
	end
end